# Cascadia Subduction Zone (CSZ)

The Cascadia subduction zone model was updated from 2008 to 2014, but remained the same in the
2018 Conterminous U.S. NSHM update. The Cascadia logic tree as a whole has the ID: `3199`.

## Magnitude Frequency Distributions (MFDs)

The single (a.k.a. 'characteristic') magnitude frequency distributions for the different sections
 and combinations thereof are based on the magnitude (area) scaling relations listed below,
 in order of increasing implied magnitude, and are identified as follows:

* `M1`: Strasser et al. (2010)
* `M2`: Murotani et al. (2008)
* `M3`: Papazachos et al. (2004)

Cascadia uses two different Gutenberg–Richter MFD's, one with `b=0.0`, and one with `b=1.0`,
both of which are used to float ruptures on the 'full' and models spanning the 3 southern sections.

For the 2014 & 2018 Conterminous U.S. NSHM update, Cascadia either ruptures in its entirety in a
so-called 'M9' event or in a series of smaller ~M8 events. Either are possible and the logic
trees for each are additive to give the overall Goldfinger et al. (2012) rate for the entire
subduction zone. Therefore there is no weighting between the 'full' and 'partial' branches of
the logic tree defined in Fig. 63 of Petersen et al. (2014). `source-groups` are used to define
additive branches and to supply scale factors.

* Original full and segmented files: `sub[0|1|2|3|4]_ch_[bot|mid|top].in`
* Original unsegmented files: `sub[0|1]_GRb[0|1]_[bot|mid|top].in`

## Section ID Groupings

The ID ranges of features used to define the geometry of current and past Casacadia models are
listed in the table below.

| Grouping              | ID Range       |
| ---------------------:|:-------------- |
| 2008 Sections         | `[3100..3103]` |
| 2014/2018 Sections    | `[3110..3142]` |
| 2014/2018 Ruptures    | `[3150..3149]` |

## Rupture Reference

The table below lists the IDs used for rupture sets on different branches of the 2014 & 2018
Casacadia logic tree.

| Sections             | 1    | 2    | 3    | 4    |                         |
|:-------------------- |:----:|:----:|:----:|:----:|:-----------------------:|
| Bottom               | 3110 | 3120 | 3130 | 3140 |                         |
| Middle               | 3111 | 3121 | 3131 | 3141 |                         |
| Top                  | 3112 | 3122 | 3132 | 3142 |                         |
| __Ruptures__         |      |      |      |      | [ Bottom, Middle, Top ] |
| Full, 1-2-3-4        | ◆    | ◆    | ◆    | ◆    | [ 3170, 3171, 3172 ]    |
| Segmented, 1         | ◆    |      |      |      | [ 3110, 3111, 3112 ]    |
| Segmented, 1-2       | ◆    | ◆    |      |      | [ 3150, 3151, 3152 ]    |
| Segmented, 1-2-3     | ◆    | ◆    | ◆    |      | [ 3160, 3161, 3162 ]    |
| Segmented, 4         |      |      |      | ◆    | [ 3140, 3141, 3142 ]    |
| Unsegmented, 1-2-3   | ◆    | ◆    | ◆    |      | [ 3160, 3161, 3162 ]    |
| Unsegmented, 1-2-3-4 | ◆    | ◆    | ◆    | ◆    | [ 3170, 3171, 3172 ]    |

## Logic Tree Weight Adjustments

__bot:__ 1.856 instead of 1.8534  
__mid:__ 1.8528 instead of 1.8534  
__top:__ 1.856 instead of 1.8534  
